"""EEGLAB module for conversion to FIF."""

# Author: Mainak Jas <mainak.jas@telecom-paristech.fr>

from .eeglab import read_raw_eeglab, read_epochs_eeglab
